@@ -2,6 +2,9 @@
 //! `Fretboard_layout` is a library for turning a set of specifications into a
 //! complete template of a stringed musical instrument fretboard, such as a
 //! guitar, banjo, or mandolin.
+//! | ![Sample output](https://jeang3nie.codeberg.page/gfret/sample.svg) |
+//! | :--: |
+//! | **Sample output** |
 //! ## Usage
 //! ```rust
 //! use fretboard_layout::{Config,Specs};
@@ -20,7 +23,7 @@
 mod config;
 pub use config::{Config, Font, FontWeight, Units};
 
-use rgba_simple::{Convert, HexColor, Primary};
+use rgba_simple::{Convert, HexColor, Primary, PrimaryColor};
 use serde::{Deserialize, Serialize};
 use std::f64;
 use svg::node::element::{path::Data, Description, Group, Path};
@@ -152,26 +155,33 @@ struct Line {
 impl Lengths {
     /// Plots the end of a fret, nut or bridge along the bass side of the scale
     fn get_point_bass(&self, specs: &Specs, config: &Config) -> Point {
-        let x = (specs.factors.x_ratio * self.length_bass) + config.border;
         let hand = specs.variant.handedness();
-        let opposite = specs.factors.y_ratio * self.length_bass;
-        let y = match hand {
-            Some(Handedness::Left) => specs.bridge - opposite + config.border,
-            _ => opposite + config.border,
+        let x = match hand {
+            Some(Handedness::Left) => {
+                specs.scale - (specs.factors.x_ratio * self.length_bass) + config.border
+            },
+            _ => (specs.factors.x_ratio * self.length_bass) + config.border,
         };
+        let opposite = specs.factors.y_ratio * self.length_bass;
+        let y = opposite + config.border;
         Point(x, y)
     }
     /// Plots the end of a fret, nut or bridge along the treble side of the scale
     fn get_point_treble(&self, specs: &Specs, config: &Config) -> Point {
-        let x = specs.factors.treble_offset
-            + (specs.factors.x_ratio * self.length_treble)
-            + config.border;
         let hand = specs.variant.handedness();
-        let opposite = specs.factors.y_ratio * self.length_treble;
-        let y = match hand {
-            Some(Handedness::Left) => opposite + config.border,
-            _ => specs.bridge - opposite + config.border,
+        let x = match hand {
+            Some(Handedness::Left) => {
+                specs.scale + config.border - specs.factors.treble_offset
+                - (specs.factors.x_ratio * self.length_treble)
+            },
+            _ => {
+                specs.factors.treble_offset
+                + (specs.factors.x_ratio * self.length_treble)
+                + config.border
+            },
         };
+        let opposite = specs.factors.y_ratio * self.length_treble;
+        let y = specs.bridge - opposite + config.border;
         Point(x, y)
     }
     /// Returns a Point struct containing both ends of a fret, nut or bridge
@@ -195,7 +205,7 @@ impl Line {
             Ok(c) => c,
             Err(e) => {
                 eprintln!("Error getting fretline color from config: {}", e);
-                HexColor::white()
+                HexColor::primary(PrimaryColor::White)
             }
         };
         let data = Data::new()
@@ -427,10 +437,10 @@ impl Specs {
                 Ok(h) => h,
                 Err(e) => {
                     eprintln!("Error getting centerline_color from config: {}", e);
-                    HexColor::blue()
+                    HexColor::primary(PrimaryColor::Blue)
                 }
             },
-            None => HexColor::blue(),
+            None => HexColor::primary(PrimaryColor::Blue),
         };
         let dasharray = match config.units {
             Units::Metric => "4.0, 8.0",
@@ -455,14 +465,16 @@ impl Specs {
     fn draw_bridge(&self, config: &Config) -> svg::node::element::Path {
         let start_x = match self.variant {
             Variant::Monoscale | Variant::Multiscale(_, Handedness::Right) => config.border,
-            Variant::Multiscale(_, Handedness::Left) => config.border + self.factors.treble_offset,
+            Variant::Multiscale(_, Handedness::Left) => config.border + self.scale,
         };
         let start_y = config.border;
         let end_x = match self.variant {
             Variant::Monoscale | Variant::Multiscale(_, Handedness::Right) => {
                 config.border + self.factors.treble_offset
-            }
-            Variant::Multiscale(_, Handedness::Left) => config.border,
+            },
+            Variant::Multiscale(_, Handedness::Left) => {
+                config.border + self.scale - self.factors.treble_offset
+            },
         };
         let end_y = config.border + self.bridge;
         let data = Data::new()
@@ -487,7 +499,7 @@ impl Specs {
             Ok(c) => c,
             Err(e) => {
                 eprintln!("Error getting fretboard color: {}", e);
-                HexColor::black()
+                HexColor::primary(PrimaryColor::Black)
             }
         };
         let data = Data::new()
